### functions to create pretty shaded Normal curve plots with 
### both the Z axis and the X axis


norm.Curve<-function(mu,sigma,xax,varLabel) {

#mu = mean of original data
#sigma = SD of original data
#xax = number of x axes to be plotted (1: just Z-axis, 2: include X-axis from original data)
#varLabel = Variable Label and Units ("X (units)")

  zSTD<-seq(-4,4,1)
  zDATA<-zSTD*sigma+mu

  #create data
  z<-seq(-3.7,3.7,length=20000)
  y<-dnorm(z)
  
  #create normal curve
  plot(z,y,type="l", lwd=2, col="black",ylab="",xlab="",axes=F)

  #manually create Z-axis
  axis(1,zSTD)
  mtext("Z",side = 1, at=-4.5,line=0.97)

  #manually create additional X-axis (original data scale)
  if (xax==2) {
     axis(1,zSTD,line=2,tick=F,labels=zDATA)  
     mtext(varLabel,side = 1, at=-4.5,line=2.9)
  }
}




norm.Curve1<-function(mu,sigma,xax,varLabel,critVal,dir) {

#mu = mean of original data
#sigma = SD of original data
#xax = number of x axes to be plotted (1: just Z-axis, 2: include X-axis from original data)
#varLabel = Variable Label and Units ("X (units)")
#critVal = value of interest on original data scale
#dir = direction to shade ("A"=above, "B"=below)

  zSTD<-seq(-4,4,1)
  zDATA<-round(zSTD*sigma+mu,1)
  zScore<-round((critVal-mu)/sigma,2)

  #create data
  z<-seq(-3.7,3.7,length=20000)
  y<-dnorm(z)
  
  #create normal curve
  plot(z,y,type="l", lwd=2, col="black",ylab="",xlab="",axes=F)

  #manually create Z-axis
  axis(1,zSTD)
  mtext("Z",side = 1, at=-4.5,line=0.97)

  #manually create additional X-axis (original data scale)
  if (xax==2) {
     axis(1,zSTD,line=2,tick=F,labels=zDATA)  
     mtext(varLabel,side = 1, at=-4.5,line=2.9)
  }

  #draw line of interest
  abline(v=zScore,lwd=3,col="blue2")
  axis(1,at=zScore,lwd.ticks=3,cex.axis=0.85,col.axis="blue2",col.ticks="blue2",mgp=c(1,0.25,0))
  
  #shade region of interest
  if (dir=="A") {
     midZ<-zScore+(max(z)-zScore)/3
     z=seq(zScore,max(z),length=20000)
     y=dnorm(z)
     polygon(c(zScore,z,max(z)),c(0,y,0),col="deepskyblue")

     if (zScore>=1.5) {
   	 text(x=midZ,y=dnorm(midZ)+0.015,labels=round(1-pnorm(zScore,0,1),4),cex=0.85,adj=c(0,0) )
     }
     else {	
	 text(x=midZ,y=dnorm(midZ)/2,labels=round(1-pnorm(zScore,0,1),4),cex=0.85,adj=c(1,1) )
     }

  }
  
  if (dir=="B") {
     midZ<-zScore-(zScore-min(z))/3
     z=seq(min(z),zScore,length=20000)
     y=dnorm(z)
     polygon(c(min(z),z,zScore),c(0,y,0),col="deepskyblue")
#  text(x=midZ,y=dnorm(midZ)+0.05,labels=round(pnorm(zScore,0,1),4) )

     if (zScore<=-1.5) {
   	 text(x=midZ,y=dnorm(midZ)+0.015,labels=round(pnorm(zScore,0,1),4),cex=0.85,adj=c(1,0) )
     }
     else {	
	 text(x=midZ,y=dnorm(midZ)/2,labels=round(pnorm(zScore,0,1),4),cex=0.85,adj=c(0,1) )
     }
  }
}

norm.Curve1(60,15,2,"X (weeks)",85,"A")
norm.Curve1(60,15,2,"X (weeks)",55,"B")



norm.Curve2<-function(mu,sigma,xax,varLabel,critVal1,critVal2) {

#mu = mean of original data
#sigma = SD of original data
#xax = number of x axes to be plotted (1: just Z-axis, 2: include X-axis from original data)
#varLabel = Variable Label and Units ("X (units)")
#critVal1 = lower value of interest on original data scale
#critVal2 = upper value of interest on original data scale

  zSTD<-seq(-4,4,1)
  zDATA<-round(zSTD*sigma+mu,1)
  zScore1<-round((critVal1-mu)/sigma,2)
  zScore2<-round((critVal2-mu)/sigma,2)
  midZ<-mean(c(zScore1,zScore2))

  #create data
  z<-seq(-3.7,3.7,length=20000)
  y<-dnorm(z)
  
  #create normal curve
  plot(z,y,type="l", lwd=2, col="black",ylab="",xlab="",axes=F)

  #manually create Z-axis
  axis(1,zSTD)
  mtext("Z",side = 1, at=-4.5,line=0.97)

  #manually create additional X-axis (original data scale)
  if (xax==2) {
     axis(1,zSTD,line=2,tick=F,labels=zDATA)  
     mtext(varLabel,side = 1, at=-4.5,line=2.9)
  }

  #draw lines of interest
  abline(v=zScore1,lwd=3,col="blue2")
  axis(1,at=zScore1,lwd.ticks=3,cex.axis=0.85,col.axis="blue2",col.ticks="blue2",mgp=c(1,0.25,0))

  abline(v=zScore2,lwd=3,col="blue2")
  axis(1,at=zScore2,lwd.ticks=3,cex.axis=0.85,col.axis="blue2",col.ticks="blue2",mgp=c(1,0.25,0))
  
  #shade region of interest

   z=seq(zScore1,zScore2,length=20000)
   y=dnorm(z)
   polygon(c(zScore1,z,zScore2),c(0,y,0),col="deepskyblue")

   text(x=midZ,y=dnorm(midZ)/2,labels=round(pnorm(zScore2,0,1)-pnorm(zScore1,0,1),4),cex=1)

}

